Documentation
¶
Overview ¶
Package model contains business logic wrappers. Alert logic has been moved to the data package.
Index ¶
- func LogMetricsCmd(cpu, memory, disk, netRate float64, procCount int, enabled bool, ...) tea.Cmd
- func SaveSnapshotCmd(cpu, memory, disk float64, processCount int) tea.Cmd
- func UpdateHealthScore(s *data.AppState)
- func UpdateProcessHistory(s *data.AppState, alivePids map[int32]bool)
- type Model
- type RenderCache
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LogMetricsCmd ¶
func UpdateHealthScore ¶ added in v0.1.3
UpdateHealthScore calculates the system health score based on critical metrics. We start with 100 points and deduct points based on severity of usage (CPU, Memory, Disk, Temp).
Types ¶
type Model ¶
type Model struct {
data.AppState
Provider struct {
System provider.SystemProvider
Process provider.ProcessProvider
Remote provider.RemoteProvider
}
// contains filtered or unexported fields
}
func InitialModel ¶
func InitialModel() *Model
func InitialModelWithConfig ¶ added in v0.6.0
Click to show internal directories.
Click to hide internal directories.